#!/bin/bash
#Quiet: -q
#Self-delete: -D

if [[ $UID != 0 ]]; then
	echo -e "\nERROR: Insufficient privileges"
	echo -e "This script must be run either:\n(1) as root, or\n(2) with sudo -"
	echo -e "\tsudo $0 $*"
	echo "Exiting..."
	exit 1
fi

for var in "$@"
do
	if [ "$var" = "-q" ]; then
		quietly=1;
	fi
	if [ "$var" = "-D" ]; then
		selfdelete=1;
	fi
done

cd "$( dirname "$0" )"

echo "Beginning setup:"
if [ $quietly ]; then echo "[quiet mode]"; fi
if [ $selfdelete ]; then echo "[self-delete mode]"; fi
echo ""

if [ ! -d /usr/lib/rtVTK ]; then mkdir /usr/lib/rtVTK; fi

for line in $(ls ./bin/libs)
do
	dir1=$(find /usr/lib -name $line)
	dir2=$(find /lib -name $line)

	if [[ (! $dir1 =~ [^[:space:]]) && (! $dir2 =~ [^[:space:]]) ]]; then
		if [ ! $quietly ]; then		
		echo "Copying $line to /usr/lib/rtVTK"
		fi
		
		if [ $selfdelete ]; then
			mv "./bin/libs/$line" /usr/lib/rtVTK
		else
			cp "./bin/libs/$line" /usr/lib/rtVTK
		fi
	else
		if [ ! $quietly ]; then
		echo "Found $line"
		fi
		
		if [ $selfdelete ]; then
		rm -f "./bin/libs/$line"
		fi
	fi
done

if [ $selfdelete ]; then
	rmdir "./bin/libs"
fi

echo -e "/usr/lib/rtVTK\n">/etc/ld.so.conf.d/rtVTK.conf
ldconfig

echo -e "\nSetup has completed..."
echo "Exiting..."
